@@ -1,15 +1,20 @@
-import pprint
+import pprint, traceback, contextlib, sys
 
-def build_exception_msg(msg, where, owner=None):
-    who = "" if owner is None else (", [%s]" % str(owner))
-    if where:
-        start_lineno, _, filepath = where
-        return 'File "%s", line %i%s\n%s' % (filepath, start_lineno, who, msg)
+def build_where_msg(where, owner, msg=None):
+    try:
+        where = 'File "%s", line %i' % (where.filepath, where.start_lineno)
+    except:
+        if where:
+            where = str(where)
 
-    if who:
-        return '%s\n%s' % (who, msg)
+    if owner:
+        owner = "[%s]" % str(owner)
+        where = ', '.join([where, owner]) if where else owner
 
-    return msg
+    if msg:
+        where += '\n' + msg
+
+    return where
 
 
 def log(msg, x):
@@ -124,3 +129,41 @@ def constant(argumentless_method):
             return val
 
     return wrapped
+
+
+@contextlib.contextmanager
+def human_exceptions(where_default, verbosity, quiet, exitcode):
+    ''' Print to stdout the message of the exception (if any)
+        suppressing its traceback.
+         - if verbosity is greather than zero, print the traceback.
+         - if quiet is True, do not print anything.
+
+        To enhance the print, print the 'where' attribute of the
+        exception (if it has one) or the 'where_default'.
+
+        Finally, exit the process with exitcode.
+    '''
+    try:
+        yield
+    except Exception as e:
+        if quiet:
+            pass
+        else:
+            where = getattr(e, 'where', where_default)
+            msg = str(e)
+            if verbosity >= 1:
+                msg = traceback.format_exc()
+
+            print("{where}\n{msg}".format(where=where, msg=msg))
+        sys.exit(exitcode)
+
+@contextlib.contextmanager
+def enhance_exceptions(where, owner):
+    where = build_where_msg(where, owner)
+    try:
+        yield
+    except Exception as e:
+        if not hasattr(e, 'where'):
+            e.where = where
+        raise e
+
