@@ -1,5 +1,6 @@
 import collections, re
-from .common import log, build_exception_msg, tohuman, print_example
+from .common import log, build_where_msg, tohuman, print_example, \
+                    enhance_exceptions
 
 Where = collections.namedtuple('Where', ['start_lineno',
                                          'end_lineno',
@@ -282,7 +283,7 @@ class ExampleHarvest(object):
         return examples
 
     def _log_drop(self, reason, where):
-        log(build_exception_msg("Dropped example: " + reason, where, self),
+        log(build_where_msg(where, self, "Dropped example: " + reason),
                 self.verbosity-2)
 
     def get_examples_using(self, finder, string, filepath='<string>'):
@@ -303,40 +304,43 @@ class ExampleHarvest(object):
             # where we are, used for the messages of the exceptions
             where = Where(start_lineno, end_lineno, filepath)
 
-            # let's find what language is about
-            language = finder.get_language_of(self.options, match, where)
-            if not language:
-                self._log_drop('language undefined', where)
-                continue
+            with enhance_exceptions(where, finder):
+                # let's find what language is about
+                language = finder.get_language_of(self.options, match, where)
 
-            if language not in self.allowed_languages:
-                self._log_drop('language %s not allowed' % language, where)
-                continue
+                if not language:
+                    self._log_drop('language undefined', where)
+                    continue
 
-            # who can parse it?
-            parser = self.parser_by_language.get(language)
-            if not parser:
-                self._log_drop('no parser found for %s language' % language, where)
-                continue # TODO should be an error?
+                if language not in self.allowed_languages:
+                    self._log_drop('language %s not allowed' % language, where)
+                    continue
 
-            # who can execute it?
-            runner = self.runner_by_language.get(language)
-            if not runner:
-                self._log_drop('no runner found for %s language' % language, where)
-                continue # TODO should be an error?
+                # who can parse it?
+                parser = self.parser_by_language.get(language)
+                if not parser:
+                    self._log_drop('no parser found for %s language' % language, where)
+                    continue # TODO should be an error?
 
-            # save the indentation here
-            indent = match.group('indent')
+                # who can execute it?
+                runner = self.runner_by_language.get(language)
+                if not runner:
+                    self._log_drop('no runner found for %s language' % language, where)
+                    continue # TODO should be an error?
 
-            # then, get the snippet (runneable code) and the expected (the string)
-            # from the example_str
-            snippet, expected = finder.get_snippet_and_expected(match, where)
+                # save the indentation here
+                indent = match.group('indent')
 
-            # perfect, we have everything to build an example
-            example = parser.build_example(snippet, expected, indent,
-                                                    runner, finder, where)
+                # then, get the snippet (runneable code) and the expected (the string)
+                # from the example_str
+                snippet, expected = finder.get_snippet_and_expected(match, where)
 
-            examples.append(example)
+            with enhance_exceptions(where, parser):
+                # perfect, we have everything to build an example
+                example = parser.build_example(snippet, expected, indent,
+                                                        runner, finder, where)
+
+                examples.append(example)
 
 
         log("File '%s': %i examples [%s]" % (filepath, len(examples), str(finder)),
@@ -380,8 +384,7 @@ class ExampleFinder(object):
             >>> check_and_remove_indent('  >>> 1 + 2\n3', '  ', (1, 2, 'foo.rst'))
             Traceback (most recent call last):
             <...>
-            ValueError: File "foo.rst", line 1, [Python Prompt Finder]
-            The line 2 is misaligned (wrong indentation). Expected at least 2 spaces.
+            ValueError: The line 2 is misaligned (wrong indentation). Expected at least 2 spaces.
             001   >>> 1 + 2
             002 3
 
@@ -390,7 +393,7 @@ class ExampleFinder(object):
             '>>> 1 + 2\n\n3'
 
         '''
-        start_lineno, _, filepath = where
+        start_lineno, _, _ = where
 
         lines = example_str.split('\n')
 
@@ -408,13 +411,13 @@ class ExampleFinder(object):
                 msg = msg % (start_lineno + lineno,
                                 len(indent),
                                 '\n'.join(context))
-                raise ValueError(build_exception_msg(msg, where, self))
+                raise ValueError(msg)
 
             indent_stripped.append(line[len(indent):])
 
         return '\n'.join(indent_stripped)
 
-    def check_keep_matching(self, example_str, match, where):
+    def check_keep_matching(self, example_str, match):
         r'''
         Given an example string, try to apply the match again.
         This is a health-check intended to be used after a call to
@@ -433,35 +436,33 @@ class ExampleFinder(object):
             >>> code_i = check_and_remove_indent(code, '  ', (1, 2, 'foo.rst'))
             >>> code_i != code
             True
-            >>> new_match = check_keep_matching(code_i, match, (1, 2, 'foo.rst'))
+            >>> new_match = check_keep_matching(code_i, match)
 
         This should not happen but if for some reason the regex doesn't match
         the full string, raise an exception:
 
             >>> x_code = 'x' + code_i
-            >>> check_keep_matching(x_code, match, (1, 2, 'foo.rst'))
+            >>> check_keep_matching(x_code, match)
             Traceback (most recent call last):
             <...>
             ValueError: <...>
 
             >>> code_x = code_i + '\nx'
-            >>> check_keep_matching(code_x, match, (1, 2, 'foo.rst'))
+            >>> check_keep_matching(code_x, match)
             Traceback (most recent call last):
             <...>
             ValueError: <...>
 
         '''
-        start_lineno, _, filepath = where
-
         new_match = match.re.match(example_str)
         if not new_match:
             msg = 'The regex does not match the example after ' +\
-                  'removing the indentation. '
+                  'removing the indentation (check_and_remove_indent). '
 
-            raise ValueError(build_exception_msg(msg, where, self))
+            raise ValueError(msg)
 
         if new_match.start() != 0 or new_match.end() != len(example_str):
-            msg = '%i bytes were left out after removing the indentation. ' +\
+            msg = '%i bytes were left out after removing the indentation (check_and_remove_indent). ' +\
                   'Dropped bytes at the %s of example:\n%s\n'
 
             if new_match.start() != 0:
@@ -472,7 +473,7 @@ class ExampleFinder(object):
                 at = 'end'
 
             msg = msg % (len(dropped), at, dropped)
-            raise ValueError(build_exception_msg(msg, where, self))
+            raise ValueError(msg)
 
         return new_match
 
@@ -493,7 +494,7 @@ class ExampleFinder(object):
 
         # check that we still can find the example
         # (allow to generate a new match)
-        match = self.check_keep_matching(example_str, match, where)
+        match = self.check_keep_matching(example_str, match)
 
         # finally, return the updated snippet and expected strings
         return match.group('snippet'), match.group('expected')
