@@ -26,12 +26,14 @@ Example:
 """
 
 import re, pexpect, sys, time
+from byexample.common import constant
 from byexample.parser import ExampleParser
 from byexample.runner import ExampleRunner, PexepctMixin
 
 class CPPParser(ExampleParser):
     language = 'cpp'
 
+    @constant
     def example_options_string_regex(self):
         # anything of the form:
         #   /*  byexample:  +FOO -BAR +ZAZ=42  */
@@ -66,7 +68,7 @@ class CPPInterpreter(ExampleRunner, PexepctMixin):
         PexepctMixin.interact(self)
 
     def initialize(self, examples, options):
-        self._spawn_interpreter()
+        self._spawn_interpreter(delaybeforesend=options['delaybeforesend'])
 
     def shutdown(self):
         self._shutdown_interpreter()
